@@ -1,14 +1,14 @@
 package Pod::Elemental::Transformer;
-our $VERSION = '0.092901';
+our $VERSION = '0.092910';
 
 
 use Moose::Role;
 use Moose::Autobox;
-# ABSTRACT: something that transforms a document tree into a new tree
+# ABSTRACT: something that transforms a node tree into a new tree
 
 use namespace::autoclean;
 
-requires 'transform_document';
+requires 'transform_node';
 
 
 1;
@@ -19,19 +19,19 @@ __END__
 
 =head1 NAME
 
-Pod::Elemental::Transformer - something that transforms a document tree into a new tree
+Pod::Elemental::Transformer - something that transforms a node tree into a new tree
 
 =head1 VERSION
 
-version 0.092901
+version 0.092910
 
 =head1 METHODS
 
-=head2 transform_document
+=head2 transform_node
 
-  my $document = $nester->transform_document($document);
+  my $node = $nester->transform_node($node);
 
-This method must produce a new Document based on the input Document.
+This method alters the given node and returns it.
 
 =head1 AUTHOR
 
